/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2014, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.test.integration.security.vault;

import org.jboss.as.arquillian.api.ServerSetupTask;
import org.jboss.as.arquillian.container.ManagementClient;
import org.jboss.as.test.module.util.TestModule;
import org.jboss.logging.Logger;

/**
 * @author <a href="mailto:pskopek@redhat.com">Peter Skopek</a>.
 */
public class ExternalPasswordModuleSetupTask implements ServerSetupTask {
    private static Logger LOGGER = Logger.getLogger(ExternalPasswordModuleSetupTask.class);

    public static final String MODULE_NAME_BASE = "org.jboss.test.vault";
    public static final String MODULE_NAME = "vaultext";
    private static final String MODULE_JAR = "external.jar";

    private static String moduleSuffix = null;

    private TestModule testModule;

    /**
     * Creates work-directory where JAR containing {@link org.jboss.as.test.integration.security.vault.ExternalPassword} is stored. The JAR is then deployed as an AS module.
     */
    @Override
    public void setup(ManagementClient managementClient, String containerId) throws Exception {
        LOGGER.info("Creating: " + getModuleName());
        testModule = new TestModule(getModuleName());
        testModule.addResource(MODULE_JAR).addClass(ExternalPassword.class);
        testModule.create();
    }

    /**
     * Removes work-directory and removes the AS module.
     */
    @Override
    public void tearDown(ManagementClient managementClient, String containerId) throws Exception {
        LOGGER.info("Removing module: " + getModuleName());
        if (testModule != null) {
            testModule.remove();
        }
        //reset module name to default
        moduleSuffix = null;
    }

    public static String getModuleName() {
        if (moduleSuffix != null) {
            return MODULE_NAME_BASE + "." + moduleSuffix;
        }
        return MODULE_NAME_BASE + "." + MODULE_NAME;
    }

    protected static void setModuleSuffix(String suffix) {
        moduleSuffix = suffix;
    }

}
